@@ -18,6 +18,7 @@ from cdp_backend.pipeline.mock_get_events import (
 )
 
 from cdp_scrapers.legistar_utils import LegistarScraper
+from cdp_scrapers.instances.portland import get_portland_events
 
 ###############################################################################
 
@@ -54,6 +55,7 @@ for submodule in iter_modules(__path__):
 # Add your scraper function here
 # SCRAPER_FUNCTIONS[{python_municipality_slug}] = {function_callable}
 SCRAPER_FUNCTIONS["test_deployment"] = get_test_deployment_events
+SCRAPER_FUNCTIONS["portland"] = get_portland_events
 
 # Set all scraper functions as exports of this module
 for python_municipality_slug, func in SCRAPER_FUNCTIONS.items():
